@@ -27,18 +27,16 @@ import os
 from inspect import getframeinfo, stack
 
 from easylogcli import util
+from easylogcli import config
 
 
 class EasyLog:
 
     def __init__(self):
-        with open('./config.json') as f:
-            self.config = json.load(f)
-
-        self.name = self.config['name']
-        self.host = self.config['host']
-        self.port = self.config['port']
-        self.absolute_path = self.config['absolute_path']
+        self.name = config.Config['name']
+        self.host = config.Config['host']
+        self.port = config.Config['port']
+        self.absolute_path = config.Config['absolute_path']
 
         self.pool = concurrent.futures.ThreadPoolExecutor(max_workers=os.cpu_count())
 
@@ -93,7 +91,8 @@ is_close:{is_close}
 def test():
     client = EasyLog()
 
-    for _ in range(10):
+    # for _ in range(999999):
+    for _ in range(3):
         client.send(message='下载图片成功')
 
     import time
